@@ -92,7 +92,7 @@ def test_kbhit_interrupted_nonetype():
         read_until_semaphore(sys.__stdin__.fileno(), semaphore=SEMAPHORE)
         os.write(sys.__stdout__.fileno(), SEMAPHORE)
         with term.raw():
-            term.inkey(timeout=None)
+            term.inkey(timeout=1)
         os.write(sys.__stdout__.fileno(), b'complete')
         assert got_sigwinch is True
         if cov is not None:
@@ -106,8 +106,6 @@ def test_kbhit_interrupted_nonetype():
         stime = time.time()
         time.sleep(0.05)
         os.kill(pid, signal.SIGWINCH)
-        time.sleep(1.0)
-        os.write(master_fd, b'X')
         output = read_until_eof(master_fd)
 
     pid, status = os.waitpid(pid, 0)
@@ -214,6 +212,21 @@ def test_cbreak_no_kb():
             with mock.patch("tty.setcbreak") as mock_setcbreak:
                 with term.cbreak():
                     assert not mock_setcbreak.called
+                assert term.keyboard_fd is None
+    child()
+
+
+def test_notty_kb_is_None():
+    "keyboard_fd should be None when os.isatty returns False."
+    # in this scenerio, stream is sys.__stdout__,
+    # but os.isatty(0) is False,
+    # such as when piping output to less(1)
+    @as_subprocess
+    def child():
+        with mock.patch("os.isatty") as mock_isatty:
+            mock_isatty.return_value = False
+            term = TestTerminal()
+            assert term.keyboard_fd is None
     child()
 
 
@@ -226,6 +239,7 @@ def test_raw_no_kb():
             with mock.patch("tty.setraw") as mock_setraw:
                 with term.raw():
                     assert not mock_setraw.called
+            assert term.keyboard_fd is None
     child()
 
 
